@@ -18,6 +18,8 @@ def extract_features_wotarget_8(inifile):
     vidInfPath = os.path.join(vidInfPath,'logs')
     vidInfPath = os.path.join(vidInfPath, 'video_info.csv')
     vidinfDf = pd.read_csv(vidInfPath)
+    #change videos name to str
+    vidinfDf.Video = vidinfDf.Video.astype('str')
 
     if not os.path.exists(csv_dir_out):
         os.makedirs(csv_dir_out)
@@ -34,6 +36,15 @@ def extract_features_wotarget_8(inifile):
     roll_windows_values = [2, 5, 6, 7.5, 15]
     loopy = 0
 
+    #REMOVE WINDOWS THAT ARE TOO SMALL
+    minimum_fps = vidinfDf['fps'].min()
+    for win in range(len(roll_windows_values)):
+        if minimum_fps < roll_windows_values[win]:
+            roll_windows_values[win] = minimum_fps
+        else:
+            pass
+    roll_windows_values = list(set(roll_windows_values))
+
     ########### FIND CSV FILES ###########
     for i in os.listdir(csv_dir_in):
         if i.__contains__(".csv"):
@@ -139,16 +150,16 @@ def extract_features_wotarget_8(inifile):
                     csv_df_combined.Tail_end_y_shifted - csv_df_combined.Tail_end_y) ** 2)) / currPixPerMM
         csv_df['Movement_mouse_left_ear'] = (np.sqrt(
             (csv_df_combined.Ear_left_x_shifted - csv_df_combined.Ear_left_x) ** 2 + (
-                    csv_df_combined.Ear_left_x - csv_df_combined.Ear_left_y) ** 2)) / currPixPerMM
+                    csv_df_combined.Ear_left_y_shifted - csv_df_combined.Ear_left_y) ** 2)) / currPixPerMM
         csv_df['Movement_mouse_right_ear'] = (np.sqrt(
             (csv_df_combined.Ear_right_x_shifted - csv_df_combined.Ear_right_x) ** 2 + (
-                    csv_df_combined.Ear_right_x - csv_df_combined.Ear_right_y) ** 2)) / currPixPerMM
+                    csv_df_combined.Ear_right_y_shifted - csv_df_combined.Ear_right_y) ** 2)) / currPixPerMM
         csv_df['Movement_mouse_lateral_left'] = (np.sqrt(
             (csv_df_combined.Lat_left_x_shifted - csv_df_combined.Lat_left_x) ** 2 + (
-                    csv_df_combined.Lat_left_x - csv_df_combined.Lat_left_y) ** 2)) / currPixPerMM
+                    csv_df_combined.Lat_left_y_shifted - csv_df_combined.Lat_left_y) ** 2)) / currPixPerMM
         csv_df['Movement_mouse_lateral_right'] = (np.sqrt(
             (csv_df_combined.Lat_right_x_shifted - csv_df_combined.Lat_right_x) ** 2 + (
-                    csv_df_combined.Lat_right_x - csv_df_combined.Lat_right_y) ** 2)) / currPixPerMM
+                    csv_df_combined.Lat_right_y_shifted - csv_df_combined.Lat_right_y) ** 2)) / currPixPerMM
         csv_df['Mouse_polygon_size_change'] = (
                 csv_df_combined['Mouse_poly_area_shifted'] - csv_df_combined['Mouse_poly_area'])
 
@@ -396,6 +407,9 @@ def extract_features_wotarget_8(inifile):
         fileName = fileName.split('.')
         fileOut = str(fileName[0]) + str('.csv')
         saveFN = os.path.join(csv_dir_out, fileOut)
+
+
+
         csv_df.to_csv(saveFN)
         print('Feature extraction complete for ' + '"' + str(currVidName) + '".')
     print('All feature extraction complete.')
\ No newline at end of file
