@@ -19,6 +19,8 @@ def extract_features_wotarget_9(inifile):
     vidInfPath = os.path.join(vidInfPath, 'logs')
     vidInfPath = os.path.join(vidInfPath, 'video_info.csv')
     vidinfDf = pd.read_csv(vidInfPath)
+    #change videos name to str
+    vidinfDf.Video = vidinfDf.Video.astype('str')
 
     if not os.path.exists(csv_dir_out):
         os.makedirs(csv_dir_out)
@@ -34,6 +36,15 @@ def extract_features_wotarget_9(inifile):
     roll_windows_values = [2, 5, 6, 7.5, 15]
     loopy = 0
 
+    #REMOVE WINDOWS THAT ARE TOO SMALL
+    minimum_fps = vidinfDf['fps'].min()
+    for win in range(len(roll_windows_values)):
+        if minimum_fps < roll_windows_values[win]:
+            roll_windows_values[win] = minimum_fps
+        else:
+            pass
+    roll_windows_values = list(set(roll_windows_values))
+
     filesFound = glob.glob(csv_dir_in + '/*.csv')
     print('Extracting features from ' + str(len(filesFound)) + ' files...')
     print('Extracting features from ' + str(len(filesFound)) + ' file(s)...')
